@@ -1,7 +1,8 @@
 #include "config.h"
 
-#include <cstdarg>
+#include "extensions.h"
 
+#include <cstdarg>
 #include <cstdio>
 
 #include "download/download_main.h"
@@ -13,12 +14,11 @@
 #include "torrent/download_info.h"
 #include "torrent/object_stream.h"
 #include "torrent/net/network_config.h"
+#include "torrent/net/network_manager.h"
 #include "torrent/net/socket_address.h"
 #include "torrent/peer/connection_list.h"
 #include "torrent/peer/peer_info.h"
 
-#include "extensions.h"
-
 namespace torrent {
 
 template <>
@@ -107,7 +107,7 @@ ProtocolExtension::generate_handshake_message() {
   if ((config::network_config()->encryption_options() & net::NetworkConfig::encryption_allow_incoming) != 0)
     message[key_e] = (config::network_config()->encryption_options() & net::NetworkConfig::encryption_require) != 0;
 
-  message[key_p] = config::network_config()->listen_port_or_throw();
+  message[key_p] = runtime::network_manager()->listen_port_or_throw();
   message[key_v] = raw_string::from_c_str("libTorrent " VERSION);
   message[key_reqq] = 2048;  // maximum request queue size
 
@@ -174,6 +174,7 @@ ProtocolExtension::generate_ut_pex_message(const PEXList& added, const PEXList&
   end += removed_len;
 
   *end++ = 'e';
+
   if (end - buffer > 32 + added_len + removed_len)
     throw internal_error("ProtocolExtension::ut_pex_message wrote beyond buffer.");
 
@@ -300,19 +301,7 @@ ProtocolExtension::parse_ut_pex() {
   if (!message[key_pex_added].is_raw_string())
     return true;
 
-  raw_string peers = message[key_pex_added].as_raw_string();
-
-  if (peers.empty())
-    return true;
-
-  // TODO: Sort the list before adding it.
-  AddressList l;
-
-  l.parse_address_compact(peers);
-  l.sort_and_unique();
-
-  m_download->peer_list()->insert_available(&l);
-
+  m_download->peer_list()->insert_pex_list(message[key_pex_added].as_raw_string());
   return true;
 }
 
